@extends('layouts.app')

@section('title', __('sale.pos_sale'))

@section('css')
    <style type="text/css">
        .form-control {
            height: 40px;
            padding: 5px;
        }
        .select2-container--default .select2-selection--single {
            height: 40px;
            padding: 5px 0.5rem;
        }

        .select2-container--default .select2-selection--single .select2-selection__arrow b {
            margin-top: -5px !important;
        }

        .table {
            width: 100%;
            max-width: 100%;
            margin-bottom: 0px !important;
        }

        label {
            margin-bottom: 0 !important;
        }

        @media screen {
            #printSection {
                display: none;
            }
        }

        @media print {

            #printSection,
            #printSection * {
                visibility: visible;
            }

            #printSection {
                position: absolute;
                left: 0;
                top: 0;
            }
        }
    </style>
@endsection

@section('content')

    <input type="hidden" id="amount_rounding_method" value="{{ $pos_settings['amount_rounding_method'] ?? '' }}">
    @if (!empty($pos_settings['allow_overselling']))
        <input type="hidden" id="is_overselling_allowed">
    @endif
    @if (session('business.enable_rp') == 1)
        <input type="hidden" id="reward_point_enabled">
    @endif
    @php
        $is_discount_enabled = $pos_settings['disable_discount'] != 1 ? true : false;
        $is_rp_enabled = session('business.enable_rp') == 1 ? true : false;
    @endphp

    <div class="pos-table  no-print">
        {!! Form::open(['url' => action('SellPosController@store'), 'method' => 'post', 'id' => 'add_pos_sell_form']) !!}
        {!! Form::hidden('location_id', $default_location->id ?? null, [
            'id' => 'location_id',
            'data-receipt_printer_type' => !empty($default_location->receipt_printer_type)
                ? $default_location->receipt_printer_type
                : 'browser',
            'data-default_payment_accounts' => $default_location->default_payment_accounts ?? '',
        ]) !!}
        <!-- sub_type -->
        {!! Form::hidden('sub_type', isset($sub_type) ? $sub_type : null) !!}
        <input type="hidden" id="item_addition_method" value="{{ $business_details->item_addition_method }}">
        
        @include('sale_pos.partials.pos_form')
      
        @include('sale_pos.partials.payment_modal')
        @if (empty($pos_settings['disable_suspend']))
            @include('sale_pos.partials.suspend_note_modal')
        @endif
        @if (!empty($restaurant_settings['enable_kot']))
            @include('sale_pos.partials.place_order_modal')
        @endif
        @if (empty($pos_settings['disable_recurring_invoice']))
            @include('sale_pos.partials.recurring_invoice_modal')
        @endif
    </div>
    <div class="sidebar no-print">
    @if (empty($pos_settings['hide_product_suggestion']) && !isMobile())
        @include('sale_pos.partials.pos_sidebar')
    @endif
    </div> 
        @include('sale_pos.partials.pos_form_actions')

    {!! Form::close() !!}

    <!-- This will be printed -->
    <section class="invoice print_section" id="receipt_section">
    </section>
    <div class="modal fade contact_modal" tabindex="-1" role="dialog" aria-labelledby="gridSystemModalLabel">
        @include('contact.create', ['quick_add' => true])
    </div>
    @if (empty($pos_settings['hide_product_suggestion']) && isMobile())
        @include('sale_pos.partials.mobile_product_suggestions')
    @endif
    <!-- /.content -->
    <div class="modal fade register_details_modal" tabindex="-1" role="dialog" aria-labelledby="gridSystemModalLabel">
    </div>
    <div class="modal fade close_register_modal" tabindex="-1" role="dialog" aria-labelledby="gridSystemModalLabel">
    </div>
    <!-- quick product modal -->
    <div class="modal fade quick_add_product_modal" tabindex="-1" role="dialog" aria-labelledby="modalTitle"></div>
    <div class="modal fade" id="expense_modal" tabindex="-1" role="dialog" aria-labelledby="gridSystemModalLabel">
    </div>

    @include('sale_pos.partials.configure_search_modal')

    @include('sale_pos.partials.recent_transactions_modal')

    @include('sale_pos.partials.mobile_products_modal')

    @include('sale_pos.partials.weighing_scale_modal')



@endsection
@section('css')
    <!-- include module css -->
    @if (!empty($pos_module_data))
        @foreach ($pos_module_data as $key => $value)
            @if (!empty($value['module_css_path']))
                @includeIf($value['module_css_path'])
            @endif
        @endforeach
    @endif
@stop
@section('javascript')

    <script src="{{ asset('js/pos.js?v=' . $asset_v) }}"></script>
    <script src="{{ asset('js/pos_extra.js?v=' . $asset_v) }}"></script>
    <script src="{{ asset('js/calculator.js?v=' . $asset_v) }}"></script>
    <script src="{{ asset('js/printer.js?v=' . $asset_v) }}"></script>
    <script src="{{ asset('js/product.js?v=' . $asset_v) }}"></script>
    <script src="{{ asset('js/opening_stock.js?v=' . $asset_v) }}"></script>

    @include('sale_pos.partials.keyboard_shortcuts')

    <!-- Call restaurant module if defined -->
    @if (in_array('tables', $enabled_modules) ||
            in_array('modifiers', $enabled_modules) ||
            in_array('service_staff', $enabled_modules))
        <script src="{{ asset('js/restaurant.js?v=' . $asset_v) }}"></script>
    @endif
    <!-- include module js -->
    @if (!empty($pos_module_data))
        @foreach ($pos_module_data as $key => $value)
            @if (!empty($value['module_js_path']))
                @includeIf($value['module_js_path'], ['view_data' => $value['view_data']])
            @endif
        @endforeach
    @endif

@endsection
