@extends('layouts.app')

@php
	if (!empty($status) && $status == 'quotation') {
		$title = __('lang_v1.add_quotation');
	} else if (!empty($status) && $status == 'draft') {
		$title = __('lang_v1.add_draft');
	} else {
		$title = __('sale.add_sale');
	}

	if($sale_type == 'sales_order') {
		$title = __('lang_v1.sales_order');
	}
@endphp

@section('title', $title)

@section('css')
	<style>
		.card-wrapper .content {
		    overflow: inherit!important;
		}
	</style>
@endsection

@section('content')

<div class="main-container no-print">
                
    <!-- Sub Menu -->
    <div class="horizontal-scroll">
    	@include('layouts.partials.sub_menu.invoice')
    </div>

    <!-- Card Wrapper for dashboard content -->
    <div class="card-wrapper">
		{!! Form::open(['url' => action('SellPosController@store'), 'method' => 'post', 'id' => 'add_sell_form', 'files' => true ]) !!}
        <!-- Filter through table -->
        <div class="overview-filter">
            <div class="title">
                <h1>@lang('lang_v2.add_invoice')</h1>
            </div>
			<div class="flex-17">
				@if(count($business_locations) > 0)
					<div class="form-box">
						{!! Form::select('select_location_id', $business_locations, $default_location->id ?? null, ['class' => 'form-control',
						'id' => 'select_location_id', 'required', 'autofocus', 'style' => 'width: 260px'], $bl_attributes); !!}
					</div>
				@endif

				<button type="button" class="customize-btn btn-modal" 
					data-href="{{action('SellController@customize')}}" 
					data-container=".customize_modal">
					<img src="{{ asset('img/icons/settings.svg') }}" alt="Customize" />
					Customize
				</button>
			</div>

        </div>
        <!-- End of Filter through table -->
		<br />
		<div class="product-wrapper">
			<input type="hidden" id="item_addition_method" value="{{$business_details->item_addition_method}}">
					
			@if(!empty($sale_type))
			<input type="hidden" id="sale_type" name="type" value="{{$sale_type}}">
			@endif

			<input type="hidden" id="amount_rounding_method" value="{{$pos_settings['amount_rounding_method'] ?? ''}}">
			@if(!empty($pos_settings['allow_overselling']))
				<input type="hidden" id="is_overselling_allowed">
			@endif
			@if(session('business.enable_rp') == 1)
				<input type="hidden" id="reward_point_enabled">
			@endif
			<div class="add-invoice-heading">Invoice Detail</div>
			
			<div class="ContentTwoGrid" style="align-items: flex-start">
				<div>
					<div class="form-box">
						{!! Form::label('contact_id', __('contact.customer') . ':*') !!}
						<div class="input-group">
							{!! Form::select('contact_id', 
								[], null, ['class' => 'form-control mousetrap', 'id' => 'customer_id', 'placeholder' => 'Enter Customer name / phone', 'required']); !!}
							<span class="input-group-btn">
								<button type="button" class="btn btn-default bg-white btn-flat add_new_customer" data-name=""><i class="fa fa-plus-circle text-primary fa-lg"></i></button>
							</span>
						</div>
						<small class="text-danger hide contact_due_text"><strong>@lang('account.customer_due'):</strong> <span></span></small>
					</div>

					<div class="bill-to-option">
						<button type="button">
							@lang('lang_v2.bill_to'):
							<img src="{{ asset('img/icons/pencil.svg') }}" alt="" />
							<div id="billing_address_div"></div>
						</button>

						<button type="button">
							@lang('lang_v2.ship_to'):
							<img src="{{ asset('img/icons/pencil.svg') }}" alt="" />
							<div id="shipping_address_div"></div>
						</button>
					</div>
				</div>

				<div>
					@can('edit_invoice_number')
						<div class="form-box">
							{!! Form::label('invoice_no', $sale_type == 'sales_order' ? __('restaurant.order_no') : __('sale.invoice_no') . ':') !!}
							{!! Form::text('invoice_no', null, ['class' => 'form-control', 'placeholder' => $sale_type == 'sales_order' ? __('restaurant.order_no') : __('sale.invoice_no')]); !!}
							<p style="
							color: #111827;
							font-weight: 300;
							font-size: 14px;
							padding-top: 5px;
							">@lang('lang_v1.keep_blank_to_autogenerate')</span>
						</div>
					@endcan
					
				</div>
			</div>
			<br />
			<div class="modalThreeGrid">
				<div class="form-box">
					{!! Form::label('transaction_date', __('sale.issue_date') . ':*') !!}
					<div class="input-group">
						<span class="input-group-addon">
							<i class="fa fa-calendar"></i>
						</span>
						{!! Form::text('transaction_date', $default_datetime, ['class' => 'form-control', 'readonly', 'required']); !!}
					</div>
				</div>
				@if(!empty($status))
					<input type="hidden" name="status" id="status" value="{{$status}}">

					@if(in_array($status, ['draft', 'quotation']))
						<input type="hidden" id="disable_qty_alert">
					@endif
				@else
					<div class="@if(!empty($commission_agent)) col-md-12 @else col-md-12 @endif">
						<div class="form-group">
							{!! Form::label('status', __('sale.status') . ':*') !!}
							{!! Form::select('status', $statuses, null, ['class' => 'form-control select2', 'placeholder' => __('messages.please_select'), 'required']); !!}
						</div>
					</div>
				@endif
				@if($sale_type != 'sales_order')
					<div class="col-md-12">
						<div class="form-group">
							{!! Form::label('invoice_scheme_id', __('invoice.invoice_scheme') . ':') !!}
							{!! Form::select('invoice_scheme_id', $invoice_schemes, $default_invoice_schemes->id, ['class' => 'form-control select2', 'placeholder' => __('messages.please_select')]); !!}
						</div>
					</div>
				@endif
				<div class="form-box">
					{!! Form::label('due_date', __('sale.due_date') . ':*') !!}
					<div class="input-group">
						<span class="input-group-addon">
							<i class="fa fa-calendar"></i>
						</span>
						{!! Form::text('due_date', $default_date, ['class' => 'form-control', 'readonly', 'required', 'id' => 'user_dob']); !!}
					</div>
				</div>

				<!--
					TODO multi currency-->
					<div class="form-box hidden">
					{!! Form::label('currency_id', __('business.currency') . ':') !!}
					{!! Form::select('currency_id', $currencies, $customize_invoice["currency_id"], ['placeholder' => __('business.currency'), 'required']); !!}
				</div>
			
			</div>
			<br />
		</div>
		<div class="invoice-product-quality">
			{!! Form::hidden('location_id', !empty($default_location) ? $default_location->id : null , ['id' => 'location_id', 'data-receipt_printer_type' => !empty($default_location->receipt_printer_type) ? $default_location->receipt_printer_type : 'browser', 'data-default_payment_accounts' => !empty($default_location) ? $default_location->default_payment_accounts : '']); !!}

			@php
				reset($price_groups);
			@endphp
			{!! Form::hidden('price_group', key($price_groups), ['id' => 'price_group']) !!}

			{!! Form::hidden('default_price_group', null, ['id' => 'default_price_group']) !!}
			<div class="add-invoice-form">
				{!! Form::text('search_product', null, ['class' => 'mousetrap', 'id' => 'search_product', 'placeholder' => __('lang_v2.add_product_placeholder'),
				'disabled' => is_null($default_location)? true : false,
				'autofocus' => is_null($default_location)? false : true,
				]); !!}
				<button type="button" class="pos_add_quick_product" data-href="{{action('ProductController@quickAdd')}}" data-container=".quick_add_product_modal"><img src="{{ asset('img/icons/plus.svg') }}" alt="" /></button>
				
			</div>

			<div class="invoice-quantity">
				<p>Show quantity as:</p>
				<div class="item">
					<input type="radio" id="qty" name="quantity" value="qty" />
					<label for="qty">Qty</label>
				</div>
				<div class="item">
					<input
						type="radio"
						id="hours"
						name="quantity"
						value="hours" />
					<label for="hours">Hours</label>
				</div>
				<div class="item">
					<input
						type="radio"
						id="qty-hours"
						name="quantity"
						value="qty-hours" />
					<label for="qty-hours">Qty/Hours</label>
				</div>
			</div>
		</div>
		<br />

		<div class="pos_product_div" style="min-height: 0">

			<input type="hidden" name="sell_price_tax" id="sell_price_tax" value="{{$business_details->sell_price_tax}}">

			<!-- Keeps count of product rows -->
			<input type="hidden" id="product_row_count" 
				value="0">
			@php
				$hide_tax = '';
				if( session()->get('business.enable_inline_tax') == 0){
					$hide_tax = 'hide';
				}
			@endphp
			<table class="general-table" id="pos_table">
				<thead>
					<tr>
						<th class="text-center">	
							@lang('sale.product')
						</th>
						<th class="text-center">
							@lang('sale.qty')
						</th>
						@if(!empty($pos_settings['inline_service_staff']))
							<th class="text-center">
								@lang('restaurant.service_staff')
							</th>
						@endif
						<th class="@if(!auth()->user()->can('edit_product_price_from_sale_screen')) hide @endif">
							@lang('sale.unit_price')
						</th>
						<th class="@if(!auth()->user()->can('edit_product_discount_from_sale_screen')) hide @endif">
							@lang('receipt.discount')
						</th>
						<th class="text-center {{$hide_tax}}">
							@lang('sale.tax')
						</th>
						<th class="text-center {{$hide_tax}}">
							@lang('sale.price_inc_tax')
						</th>
						
						<th class="text-center">
							@lang('sale.subtotal')
						</th>
						<th class="text-center">
							<img src="{{ asset('img/icons/settings.svg') }}" alt="" />
						</th>
					</tr>
				</thead>
				<tbody>
					
				</tbody>
			</table>
			
			<div class="invoice-product-form-total">
				@php
					$max_discount = !is_null(auth()->user()->max_sales_discount_percent) ? auth()->user()->max_sales_discount_percent : '';

					//if sale discount is more than user max discount change it to max discount
					$sales_discount = $business_details->default_sales_discount;
					if($max_discount != '' && $sales_discount > $max_discount) $sales_discount = $max_discount;

					$default_sales_tax = $business_details->default_sales_tax;

					if($sale_type == 'sales_order') {
						$sales_discount = 0;
						$default_sales_tax = null;
					}
				@endphp
				<div class="item">
					<span><b>@lang('sale.item'):</b></span>
					<span class="total_quantity">0</span>
				</div>
				<div class="item">
					<span><b>SUBTOTAL:</b></span>
					<span class="price_total">0</span>
				</div>
				<div class="item">
					
					<div class="discount-form-wrapper">
						<span>Discount</span>
						<div class="discount-form">
							{!! Form::label('discount_amount', __('sale.discount_amount') . ':*', ['style' => 'display: none']) !!}
							{!! Form::text('discount_amount', @num_format($sales_discount), ['class' => 'input_number', 'data-default' => $sales_discount, 'data-max-discount' => $max_discount, 'data-max-discount-error_msg' => __('lang_v1.max_discount_error_msg', ['discount' => $max_discount != '' ? @num_format($max_discount) : '']) ]); !!}
							{!! Form::label('discount_type', __('sale.discount_type') . ':*', ['style' => 'display: none']) !!}
							{!! Form::select('discount_type', ['fixed' => __('lang_v1.fixed'), 'percentage' => __('lang_v1.percentage')], $customize_invoice["default_discount_type"] , ['placeholder' => __('messages.please_select'), 'required', 'data-default' => 'percentage', 'id' => 'invoice_discount_type']); !!}
						</div>
					</div>
					<span class="display_currency" id="total_discount">0</span>
				</div>

				<div class="item">
					
					<div class="discount-form-wrapper">
						<span><b>@lang( 'sale.order_tax' ):</b>(+)</span>
						<div class="discount-form">
							{!! Form::label('tax_rate_id', __('sale.order_tax') . ':*', ['style' => 'display: none']) !!}
							{!! Form::select('tax_rate_id', $taxes['tax_rates'], $customize_invoice["tax_rate_id"], ['id' => 'invoice_tax_rate', 'placeholder' => __('messages.please_select'), 'data-default'=> $default_sales_tax], $taxes['attributes']); !!}

							<input type="hidden" name="tax_calculation_amount" id="tax_calculation_amount" value="@if(empty($edit)) {{@num_format($business_details->tax_calculation_amount)}} @else {{@num_format(optional($transaction->tax)->amount)}} @endif" data-default="{{$business_details->tax_calculation_amount}}">
						</div>
					</div>
					<span class="display_currency" id="order_tax">0</span>
				</div>

				<div class="item">
					@if(!empty($pos_settings['amount_rounding_method']) && $pos_settings['amount_rounding_method'] > 0)
					<small id="round_off">(@lang('lang_v1.round_off'): <span id="round_off_text">0</span>)</small>
					<br/>
					<input type="hidden" name="round_off_amount" 
						id="round_off_amount" value=0>
					@endif
					<span><b>@lang('sale.total_payable'): </b></span>
					<input type="hidden" name="final_total" id="final_total_input">
					<span id="total_payable">0</span>
				</div>
			</div>
			
		</div>

		<div class="ContentTwoGrid" style="padding: 20px">
			<div class="flex-17">
				<label class="switchBtn" for="is_recurring">
					{!! Form::checkbox('is_recurring', 1, false, ['id' => 'is_recurring']); !!}
					<div class="slider"></div>
				</label>
				<span>@lang('lang_v2.is_recurring')</span>

				<button type="button" data-toggle="modal" data-target="#recurringInvoiceModal" class="btn btn-link"><i class="fa fa-external-link"></i></button>@show_tooltip(__('lang_v1.recurring_invoice_help'))
			</div>

			<div class="flex-17">
				<label class="switchBtn" for="enable_staff">
					{!! Form::checkbox('enable_staff', 1, false, ['id' => 'enable_staff']); !!}
					<div class="slider"></div>
				</label>
				<span>@lang('lang_v2.enable_staff')</span>
			</div>
		</div>

		<div class=" is_enable_div hide">
			@if(!empty($commission_agent))
			<div class="add-invoice-heading">Staff</div>		
				<div class="row">
					 @if(!empty($status))
						<input type="hidden" name="status" id="status" value="{{$status}}">
					@else
						<div class="@if(!empty($commission_agent)) col-sm-6 @else col-sm-4 @endif">
							<div class="form-group">
								{!! Form::label('status', __('sale.status') . ':*') !!}
								{!! Form::select('status', $statuses, null, ['class' => 'form-control select2', 'placeholder' => __('messages.please_select'), 'required']); !!}
							</div>
						</div>
					@endif 

					
					@php
						$is_commission_agent_required = !empty($pos_settings['is_commission_agent_required']);
					@endphp
					<div class="col-sm-6 invoice_sales_agent @if ($customize_invoice["enable_sales_agent"] != 1) hide @endif">
						<div class="form-group">
						{!! Form::label('sales_agent', __('lang_v2.sales_agent') . ':') !!}
						{!! Form::select('sales_agent', 
									$commission_agent, null, ['class' => 'form-control select2', 'id' => 'sales_agent', 'required' => $is_commission_agent_required]); !!}
						</div>
					</div>

					<div class="col-sm-6 invoice_commission_agent @if ($customize_invoice["enable_commission_agent"] != 1) hide @endif">
						<div class="form-group">
						{!! Form::label('commission_agent', __('lang_v2.commission_agent') . ':') !!}
						{!! Form::select('commission_agent', 
									$commission_agent, null, ['class' => 'form-control select2', 'id' => 'commission_agent', 'required' => $is_commission_agent_required]); !!}
						</div>
					</div>
					
				</div>
			@endif
		</div>

		<div class="invoice-product-form-notices">
			{!! Form::label('sell_note',__('sale.sell_note')) !!}
			{!! Form::textarea('sale_note', $customize_invoice["footer_text"], ['class' => 'form-control', 'id' => 'invoice_sale_note', 'rows' => 3]); !!}

			<input type="hidden" name="is_direct_sale" value="1">
			<input type="hidden" name="invoice_prefix" id="customize_invoice_prefix" value="{{ $customize_invoice["invoice_prefix"] }}">

			@component('components.widget', ['class' => 'box-solid'])
			<div class="col-md-4">
				<div class="form-group">
		            {!! Form::label('shipping_details', __('sale.shipping_details')) !!}
		            {!! Form::textarea('shipping_details',null, ['class' => 'form-control','placeholder' => __('sale.shipping_details') ,'rows' => '3', 'cols'=>'30']); !!}
		        </div>
			</div>
			<div class="col-md-4">
				<div class="form-group">
		            {!! Form::label('shipping_address', __('lang_v1.shipping_address')) !!}
		            {!! Form::textarea('shipping_address',null, ['class' => 'form-control','placeholder' => __('lang_v1.shipping_address') ,'rows' => '3', 'cols'=>'30']); !!}
		        </div>
			</div>
			<div class="col-md-4">
				<div class="form-group">
					{!!Form::label('shipping_charges', __('sale.shipping_charges'))!!}
					<div class="input-group">
					<span class="input-group-addon">
					<i class="fa fa-info"></i>
					</span>
					{!!Form::text('shipping_charges',@num_format(0.00),['class'=>'form-control input_number','placeholder'=> __('sale.shipping_charges')]);!!}
					</div>
				</div>
			</div>
			<div class="clearfix"></div>
			<div class="col-md-4">
				<div class="form-group">
		            {!! Form::label('shipping_status', __('lang_v1.shipping_status')) !!}
		            {!! Form::select('shipping_status',$shipping_statuses, null, ['class' => 'form-control','placeholder' => __('messages.please_select')]); !!}
		        </div>
			</div>
			<div class="col-md-4">
		        <div class="form-group">
		            {!! Form::label('delivered_to', __('lang_v1.delivered_to') . ':' ) !!}
		            {!! Form::text('delivered_to', null, ['class' => 'form-control','placeholder' => __('lang_v1.delivered_to')]); !!}
		        </div>
		    </div>
			<div class="col-md-4">
				<div class="form-group">
					{!! Form::label('delivery_person', __('lang_v1.delivery_person') . ':' ) !!}
					{!! Form::select('delivery_person', $users, null, ['class' => 'form-control select2','placeholder' => __('messages.please_select')]); !!}
				</div>
			</div>
		    @php
		        $shipping_custom_label_1 = !empty($custom_labels['shipping']['custom_field_1']) ? $custom_labels['shipping']['custom_field_1'] : '';

		        $is_shipping_custom_field_1_required = !empty($custom_labels['shipping']['is_custom_field_1_required']) && $custom_labels['shipping']['is_custom_field_1_required'] == 1 ? true : false;

		        $shipping_custom_label_2 = !empty($custom_labels['shipping']['custom_field_2']) ? $custom_labels['shipping']['custom_field_2'] : '';

		        $is_shipping_custom_field_2_required = !empty($custom_labels['shipping']['is_custom_field_2_required']) && $custom_labels['shipping']['is_custom_field_2_required'] == 1 ? true : false;

		        $shipping_custom_label_3 = !empty($custom_labels['shipping']['custom_field_3']) ? $custom_labels['shipping']['custom_field_3'] : '';
		        
		        $is_shipping_custom_field_3_required = !empty($custom_labels['shipping']['is_custom_field_3_required']) && $custom_labels['shipping']['is_custom_field_3_required'] == 1 ? true : false;

		        $shipping_custom_label_4 = !empty($custom_labels['shipping']['custom_field_4']) ? $custom_labels['shipping']['custom_field_4'] : '';
		        
		        $is_shipping_custom_field_4_required = !empty($custom_labels['shipping']['is_custom_field_4_required']) && $custom_labels['shipping']['is_custom_field_4_required'] == 1 ? true : false;

		        $shipping_custom_label_5 = !empty($custom_labels['shipping']['custom_field_5']) ? $custom_labels['shipping']['custom_field_5'] : '';
		        
		        $is_shipping_custom_field_5_required = !empty($custom_labels['shipping']['is_custom_field_5_required']) && $custom_labels['shipping']['is_custom_field_5_required'] == 1 ? true : false;
	        @endphp

	        @if(!empty($shipping_custom_label_1))
	        	@php
	        		$label_1 = $shipping_custom_label_1 . ':';
	        		if($is_shipping_custom_field_1_required) {
	        			$label_1 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_1', $label_1 ) !!}
			            {!! Form::text('shipping_custom_field_1', !empty($walk_in_customer['shipping_custom_field_details']['shipping_custom_field_1']) ? $walk_in_customer['shipping_custom_field_details']['shipping_custom_field_1'] : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_1, 'required' => $is_shipping_custom_field_1_required]); !!}
			        </div>
			    </div>
	        @endif
	        @if(!empty($shipping_custom_label_2))
	        	@php
	        		$label_2 = $shipping_custom_label_2 . ':';
	        		if($is_shipping_custom_field_2_required) {
	        			$label_2 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_2', $label_2 ) !!}
			            {!! Form::text('shipping_custom_field_2', !empty($walk_in_customer['shipping_custom_field_details']['shipping_custom_field_2']) ? $walk_in_customer['shipping_custom_field_details']['shipping_custom_field_2'] : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_2, 'required' => $is_shipping_custom_field_2_required]); !!}
			        </div>
			    </div>
	        @endif
	        @if(!empty($shipping_custom_label_3))
	        	@php
	        		$label_3 = $shipping_custom_label_3 . ':';
	        		if($is_shipping_custom_field_3_required) {
	        			$label_3 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_3', $label_3 ) !!}
			            {!! Form::text('shipping_custom_field_3', !empty($walk_in_customer['shipping_custom_field_details']['shipping_custom_field_3']) ? $walk_in_customer['shipping_custom_field_details']['shipping_custom_field_3'] : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_3, 'required' => $is_shipping_custom_field_3_required]); !!}
			        </div>
			    </div>
	        @endif
	        @if(!empty($shipping_custom_label_4))
	        	@php
	        		$label_4 = $shipping_custom_label_4 . ':';
	        		if($is_shipping_custom_field_4_required) {
	        			$label_4 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_4', $label_4 ) !!}
			            {!! Form::text('shipping_custom_field_4', !empty($walk_in_customer['shipping_custom_field_details']['shipping_custom_field_4']) ? $walk_in_customer['shipping_custom_field_details']['shipping_custom_field_4'] : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_4, 'required' => $is_shipping_custom_field_4_required]); !!}
			        </div>
			    </div>
	        @endif
	        @if(!empty($shipping_custom_label_5))
	        	@php
	        		$label_5 = $shipping_custom_label_5 . ':';
	        		if($is_shipping_custom_field_5_required) {
	        			$label_5 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_5', $label_5 ) !!}
			            {!! Form::text('shipping_custom_field_5', !empty($walk_in_customer['shipping_custom_field_details']['shipping_custom_field_5']) ? $walk_in_customer['shipping_custom_field_details']['shipping_custom_field_5'] : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_5, 'required' => $is_shipping_custom_field_5_required]); !!}
			        </div>
			    </div>
	        @endif
	        <div class="col-md-4">
                <div class="form-group">
                    {!! Form::label('shipping_documents', __('lang_v1.shipping_documents') . ':') !!}
                    {!! Form::file('shipping_documents[]', ['id' => 'shipping_documents', 'multiple', 'accept' => implode(',', array_keys(config('constants.document_upload_mimes_types')))]); !!}
                    <p class="help-block">
                    	@lang('purchase.max_file_size', ['size' => (config('constants.document_size_limit') / 1000000)])
                    	@includeIf('components.document_help_text')
                    </p>
                </div>
            </div>
	        <div class="clearfix"></div>
			<div class="col-md-12 text-center">
									<button type="button" class="btn bg-yellow " id="toggle_additional_expense"> <i class="fas fa-plus"></i> @lang('lang_v1.add_additional_expenses') <i class="fas fa-chevron-down"></i></button>
									
								</div>
			<div class="col-md-8 col-md-offset-4" id="additional_expenses_div" style="display: none;">
				<table class="table table-condensed">
					<thead>
						<tr>
							<th>@lang('lang_v1.additional_expense_name')</th>
							<th>@lang('sale.amount')</th>
						</tr>
					</thead>
					<tbody>
						<tr>
							<td>
								{!! Form::text('additional_expense_key_1', null, ['class' => 'form-control', 'id' => 'additional_expense_key_1']); !!}
							</td>
							<td>
								{!! Form::text('additional_expense_value_1', 0, ['class' => 'form-control input_number', 'id' => 'additional_expense_value_1']); !!}
							</td>
						</tr>
						<tr>
							<td>
								{!! Form::text('additional_expense_key_2', null, ['class' => 'form-control', 'id' => 'additional_expense_key_2']); !!}
							</td>
							<td>
								{!! Form::text('additional_expense_value_2', 0, ['class' => 'form-control input_number', 'id' => 'additional_expense_value_2']); !!}
							</td>
						</tr>
						<tr>
							<td>
								{!! Form::text('additional_expense_key_3', null, ['class' => 'form-control', 'id' => 'additional_expense_key_3']); !!}
							</td>
							<td>
								{!! Form::text('additional_expense_value_3', 0, ['class' => 'form-control input_number', 'id' => 'additional_expense_value_3']); !!}
							</td>
						</tr>
						<tr>
							<td>
								{!! Form::text('additional_expense_key_4', null, ['class' => 'form-control', 'id' => 'additional_expense_key_4']); !!}
							</td>
							<td>
								{!! Form::text('additional_expense_value_4', 0, ['class' => 'form-control input_number', 'id' => 'additional_expense_value_4']); !!}
							</td>
						</tr>
					</tbody>
				</table>
			</div>
		    <div class="col-md-4 col-md-offset-8">
		    	@if(!empty($pos_settings['amount_rounding_method']) && $pos_settings['amount_rounding_method'] > 0)
		    	<small id="round_off"><br>(@lang('lang_v1.round_off'): <span id="round_off_text">0</span>)</small>
				<br/>
				<input type="hidden" name="round_off_amount" 
					id="round_off_amount" value=0>
				@endif
		    	<div><b>@lang('sale.total_payable'): </b>
					<input type="hidden" name="final_total" id="final_total_input">
					<span id="total_payable">0</span>
				</div>
		    </div>
			@endcomponent
		
		</div>

		<div class="invoice-footer">
			{!! Form::hidden('is_save_and_print', 0, ['id' => 'is_save_and_print']); !!}
			{!! Form::hidden('is_save_as_draft', 0, ['id' => 'is_save_as_draft']); !!}
			{!! Form::hidden('is_save_and_send', 0, ['id' => 'is_save_and_send']); !!}
			{!! Form::hidden('is_save_and_record_payment', 0, ['id' => 'is_save_and_record_payment']); !!}

			<button class="save-btn" id="submit-sell">Save</button>
			<!--<button class="save-send-btn" id="save-and-send">Save & Send</button>-->
			<button type="button" class="save-record-payment" id="save-and-record-payment">Save & Record Payment</button>
			
			@if(empty($pos_settings['disable_recurring_invoice']))
				@include('sale_pos.partials.recurring_invoice_modal')
			@endif
		</div>

		@include('sell.partials.payment_modal')
		
		{!! Form::close() !!}
    </div>

</div>


<!-- quick product modal -->
<div class="modal fade quick_add_product_modal" tabindex="-1" role="dialog" aria-labelledby="modalTitle"></div>

<div class="modal fade contact_modal" tabindex="-1" role="dialog" aria-labelledby="gridSystemModalLabel">
	@include('contact.create', ['quick_add' => true])
</div>
<!-- /.content -->
<div class="modal fade register_details_modal" tabindex="-1" role="dialog" 
	aria-labelledby="gridSystemModalLabel">
</div>
<div class="modal fade close_register_modal" tabindex="-1" role="dialog" 
	aria-labelledby="gridSystemModalLabel">
</div>

<div class="modal fade customize_modal" tabindex="-1" role="dialog" 
        aria-labelledby="gridSystemModalLabel">


@stop

@section('javascript')
	<script src="{{ asset('js/pos.js?v=' . $asset_v) }}"></script>
	<script src="{{ asset('js/product.js?v=' . $asset_v) }}"></script>
	<script src="{{ asset('js/opening_stock.js?v=' . $asset_v) }}"></script>

	<!-- Call restaurant module if defined -->
    @if(in_array('tables' ,$enabled_modules) || in_array('modifiers' ,$enabled_modules) || in_array('service_staff' ,$enabled_modules))
    	<script src="{{ asset('js/restaurant.js?v=' . $asset_v) }}"></script>
    @endif

	<script>
		$("#enable_staff").click(function() {
            var checked = $(this).is(':checked');
            if (checked) {
                $('div.is_enable_div').removeClass('hide');

            } else {
                $('div.is_enable_div').addClass('hide');
            }

        });

		 //pay and add payment
		 $('button#save-and-record-payment').click(function() {
			//Check if product is present or not.
			if ($('table#pos_table tbody').find('.product_row').length <= 0) {
				toastr.warning(LANG.no_products_added);
				return false;
			}

			$('#modal_payment').modal('show');
		});

		$('#modal_payment').one('shown.bs.modal', function() {
			//set is save and record payment to 1 once modal is opened.
			$('#is_save_and_record_payment').val(1); 
    	});

		$('#modal_payment').on('hide.bs.modal', function (e) {
			//set is save and record payment to 0 once modal is closed.
			$('#is_save_and_record_payment').val(0);
		});
	</script>
    
@endsection
