@extends('layouts.app')

@php
	$title = $transaction->type == 'sales_order' ? __('lang_v1.edit_sales_order') : __('sale.edit_sale');
@endphp
@section('title', $title)

@section('css')
	<style>
		.card-wrapper .content {
		    overflow: inherit!important;
		}
	</style>
@endsection

@section('content')

<div class="main-container no-print">       
    <!-- Sub Menu -->
    <div class="horizontal-scroll">
    	@if(!empty($status) && $status == 'quotation')
        	@include('layouts.partials.sub_menu.quotation')
        @else
        	@include('layouts.partials.sub_menu.sell')
        @endif
    </div>

    <!-- Card Wrapper for dashboard content -->
    <div class="card-wrapper">
        <!-- Filter through table -->
        <div class="overview-filter">
            <div class="title">
                <h1>{{$title}}</h1>
                <p> <small>(@if($transaction->type == 'sales_order') @lang('restaurant.order_no') @else @lang('sale.invoice_no') @endif: <span class="text-success">#{{$transaction->invoice_no}})</span></small></p>
            </div>
        </div>
        <!-- End of Filter through table -->

        <div class="content">
            <input type="hidden" id="amount_rounding_method" value="{{$pos_settings['amount_rounding_method'] ?? ''}}">
			<input type="hidden" id="amount_rounding_method" value="{{$pos_settings['amount_rounding_method'] ?? 'none'}}">
			@if(!empty($pos_settings['allow_overselling']))
				<input type="hidden" id="is_overselling_allowed">
			@endif
			@if(session('business.enable_rp') == 1)
			    <input type="hidden" id="reward_point_enabled">
			@endif
			@php
				$custom_labels = json_decode(session('business.custom_labels'), true);
				$common_settings = session()->get('business.common_settings');
			@endphp
			<input type="hidden" id="item_addition_method" value="{{$business_details->item_addition_method}}">
				{!! Form::open(['url' => action('SellPosController@update', [$transaction->id]), 'method' => 'post', 'id' => 'edit_sell_form', 'files' => true ]) !!}
				{{ method_field('PUT') }}
				{!! Form::hidden('location_id', $transaction->location_id, ['id' => 'location_id', 'data-receipt_printer_type' => !empty($location_printer_type) ? $location_printer_type : 'browser', 'data-default_payment_accounts' => $transaction->location->default_payment_accounts]); !!}

				@if($transaction->type == 'sales_order')
				 	<input type="hidden" id="sale_type" value="{{$transaction->type}}">
				@endif
				<div class="add-invoice-heading">Invoice Detail</div>
				<div class="row">
					<div class="col-md-12 col-sm-12">
						@component('components.widget', ['class' => 'box-solid'])
							@if(!empty($transaction->selling_price_group_id))
								<div class="col-md-4 col-sm-6">
									<div class="form-group">
										<div class="input-group">
											<span class="input-group-addon">
												<i class="fas fa-money-bill-alt"></i>
											</span>
											{!! Form::hidden('price_group', $transaction->selling_price_group_id, ['id' => 'price_group']) !!}
											{!! Form::text('price_group_text', $transaction->price_group->name, ['class' => 'form-control', 'readonly']); !!}
											<span class="input-group-addon">
												@show_tooltip(__('lang_v1.price_group_help_text'))
											</span> 
										</div>
									</div>
								</div>
							@endif

							@if(in_array('types_of_service', $enabled_modules) && !empty($transaction->types_of_service))
								<div class="col-md-4 col-sm-6">
									<div class="form-group">
										<div class="input-group">
											<span class="input-group-addon">
												<i class="fas fa-external-link-square-alt text-primary service_modal_btn"></i>
											</span>
											{!! Form::text('types_of_service_text', $transaction->types_of_service->name, ['class' => 'form-control', 'readonly']); !!}

											{!! Form::hidden('types_of_service_id', $transaction->types_of_service_id, ['id' => 'types_of_service_id']) !!}

											<span class="input-group-addon">
												@show_tooltip(__('lang_v1.types_of_service_help'))
											</span> 
										</div>
										<small><p class="help-block @if(empty($transaction->selling_price_group_id)) hide @endif" id="price_group_text">@lang('lang_v1.price_group'): <span>@if(!empty($transaction->selling_price_group_id)){{$transaction->price_group->name}}@endif</span></p></small>
									</div>
								</div>
								<div class="modal fade types_of_service_modal" tabindex="-1" role="dialog" aria-labelledby="gridSystemModalLabel">
									@if(!empty($transaction->types_of_service))
									@include('types_of_service.pos_form_modal', ['types_of_service' => $transaction->types_of_service])
									@endif
								</div>
							@endif

							@if(in_array('subscription', $enabled_modules))
								<div class="col-md-4 pull-right col-sm-6">
									<div class="checkbox">
										<label>
							              {!! Form::checkbox('is_recurring', 1, $transaction->is_recurring, ['class' => 'input-icheck', 'id' => 'is_recurring']); !!} @lang('lang_v1.subscribe')?
							            </label><button type="button" data-toggle="modal" data-target="#recurringInvoiceModal" class="btn btn-link"><i class="fa fa-external-link"></i></button>
									</div>
								</div>
							@endif
							
							<div class="@if(!empty($commission_agent)) col-sm-6 @else col-sm-6 @endif">
								<div class="form-group">
									{!! Form::label('contact_id', __('contact.customer') . ':*') !!}
									<div class="input-group">
										<input type="hidden" id="default_customer_id" 
										value="{{ $transaction->contact->id }}" >
										<input type="hidden" id="default_customer_name" 
										value="{{ $transaction->contact->name }}" >
										{!! Form::select('contact_id', 
											[], null, ['class' => 'form-control mousetrap', 'id' => 'customer_id', 'placeholder' => 'Enter Customer name / phone', 'required']); !!}
										<span class="input-group-btn">
											<button type="button" class="btn btn-default bg-white btn-flat add_new_customer" data-name=""><i class="fa fa-plus-circle text-primary fa-lg"></i></button>
										</span>
									</div>
									<small class="text-danger @if(empty($customer_due)) hide @endif contact_due_text"><strong>@lang('account.customer_due'):</strong> <span>{{$customer_due ?? ''}}</span></small>
								</div>
								
							</div>

							<div class="clearfix"></div>
							
							@can('edit_invoice_number')
							<div class="col-sm-4">
								<div class="form-group">
									{!! Form::label('invoice_no', $transaction->type == 'sales_order' ? __('restaurant.order_no'): __('sale.invoice_no') . ':') !!}
									{!! Form::text('invoice_no', $transaction->invoice_no, ['class' => 'form-control', 'placeholder' => $transaction->type == 'sales_order' ? __('restaurant.order_no'): __('sale.invoice_no')]); !!}
								</div>
							</div>
							@endcan
							<div class="@if(!empty($commission_agent)) col-sm-4 @else col-sm-4 @endif">
								<div class="form-group">
									{!! Form::label('transaction_date', __('sale.sale_date') . ':*') !!}
									<div class="input-group">
										<span class="input-group-addon">
											<i class="fa fa-calendar"></i>
										</span>
										{!! Form::text('transaction_date', $transaction->transaction_date, ['class' => 'form-control', 'readonly', 'required']); !!}
									</div>
								</div>
							</div>
							<div class="col-sm-4">
								<div class="form-group">
								  <div class="multi-input">
									  @php
										  $is_pay_term_required = !empty($pos_settings['is_pay_term_required']);
									  @endphp
									{!! Form::label('pay_term_number', __('contact.pay_term') . ':') !!} <br>
									{!! Form::number('pay_term_number', $transaction->pay_term_number, ['class' => 'form-control width-40 pull-left', 'placeholder' => __('contact.pay_term'), 'required' => $is_pay_term_required]); !!}
  
									{!! Form::select('pay_term_type', 
										['months' => __('lang_v1.months'), 
											'days' => __('lang_v1.days')], 
											$transaction->pay_term_type, 
										['class' => 'form-control width-60 pull-left','placeholder' => __('messages.please_select'), 'required' => $is_pay_term_required]); !!}
								  </div>
								</div>
							</div>
					</div>
					@if(!empty($commission_agent))
						<div class="add-invoice-heading">Currency & Staff</div>		
							
								
								@php
									$is_commission_agent_required = !empty($pos_settings['is_commission_agent_required']);
								@endphp
									<div class="col-sm-12">
										<div class="form-group">
										{!! Form::label('commission_agent', __('lang_v2.sales_agent') . ':') !!}
										{!! Form::select('commission_agent', 
													$commission_agent, null, ['class' => 'form-control select2', 'id' => 'commission_agent', 'required' => $is_commission_agent_required]); !!}
										</div>
									</div>
							
					@endif
							  
					<div class="row">	
						@endcomponent
						
						@component('components.widget', ['class' => 'box-solid'])
							<div class="col-sm-10 col-sm-offset-1">
								<div class="form-group">
									<div class="input-group">
										<div class="input-group-btn">
											<button type="button" class="btn btn-default bg-white btn-flat" data-toggle="modal" data-target="#configure_search_modal" title="{{__('lang_v1.configure_product_search')}}"><i class="fas fa-search-plus"></i></button>
										</div>
										{!! Form::text('search_product', null, ['class' => 'form-control mousetrap', 'id' => 'search_product', 'placeholder' => __('lang_v1.search_product_placeholder'),
										'autofocus' => true,
										]); !!}
										<span class="input-group-btn">
											<button type="button" class="btn btn-default bg-white btn-flat pos_add_quick_product" data-href="{{action('ProductController@quickAdd')}}" data-container=".quick_add_product_modal"><i class="fa fa-plus-circle text-primary fa-lg"></i></button>
										</span>
									</div>
								</div>
							</div>

							<div class="row col-sm-12 pos_product_div" style="min-height: 0">

								<input type="hidden" name="sell_price_tax" id="sell_price_tax" value="{{$business_details->sell_price_tax}}">

								<!-- Keeps count of product rows -->
								<input type="hidden" id="product_row_count" 
									value="{{count($sell_details)}}">
								@php
									$hide_tax = '';
									if( session()->get('business.enable_inline_tax') == 0){
										$hide_tax = 'hide';
									}
								@endphp
								<div class="table-responsive" style="min-height: .01%; overflow-x: auto;">
								<table class="table table-condensed table-bordered table-striped table-responsive max-table" id="pos_table">
									<thead>
										<tr>
											<th class="text-center">	
												@lang('sale.product')
											</th>
											<th class="text-center">
												@lang('sale.qty')
											</th>
											@if(!empty($pos_settings['inline_service_staff']))
												<th class="text-center">
													@lang('restaurant.service_staff')
												</th>
											@endif
											<th class="@if(!auth()->user()->can('edit_product_price_from_sale_screen')) hide @endif">
												@lang('sale.unit_price')
											</th>
											<th class="@if(!auth()->user()->can('edit_product_discount_from_sale_screen')) hide @endif">
												@lang('receipt.discount')
											</th>
											<th class="text-center {{$hide_tax}}">
												@lang('sale.tax')
											</th>
											<th class="text-center {{$hide_tax}}">
												@lang('sale.price_inc_tax')
											</th>
											
											<th class="text-center">
												@lang('sale.subtotal')
											</th>
											<th class="text-center"><i class="fa fa-close" aria-hidden="true"></i></th>
										</tr>
									</thead>
									<tbody>
										@foreach($sell_details as $sell_line)
											@include('sale_pos.product_row', ['product' => $sell_line, 'row_count' => $loop->index, 'tax_dropdown' => $taxes, 'sub_units' => !empty($sell_line->unit_details) ? $sell_line->unit_details : [], 'action' => 'edit', 'is_direct_sell' => true, 'so_line' => $sell_line->so_line, 'is_sales_order' => $transaction->type == 'sales_order'])
										@endforeach
									</tbody>
								</table>
								</div>
								<div class="invoice-product-form-total">
									@php
										$max_discount = !is_null(auth()->user()->max_sales_discount_percent) ? auth()->user()->max_sales_discount_percent : '';
									@endphp
									<div class="item">
										<span><b>@lang('sale.item'):</b></span>
										<span class="total_quantity">0</span>
									</div>
									<div class="item">
										<span><b>SUBTOTAL:</b></span>
										<span class="price_total">0</span>
									</div>
									<div class="item">
										
										<div class="discount-form-wrapper">
											<span>Discount</span>
											<div class="discount-form">
												{!! Form::label('discount_amount', __('sale.discount_amount') . ':*', ['style' => 'display: none']) !!}
												{!! Form::text('discount_amount', @num_format($transaction->discount_amount), ['class' => 'input_number', 'data-default' => $business_details->default_sales_discount, 'data-max-discount' => $max_discount, 'data-max-discount-error_msg' => __('lang_v1.max_discount_error_msg', ['discount' => $max_discount != '' ? @num_format($max_discount) : '']) ]); !!}
												{!! Form::label('discount_type', __('sale.discount_type') . ':*', ['style' => 'display: none']) !!}
												{!! Form::select('discount_type', ['fixed' => __('lang_v1.fixed'), 'percentage' => __('lang_v1.percentage')], $transaction->discount_type , ['placeholder' => __('messages.please_select'), 'required', 'data-default' => 'percentage']); !!}
											</div>
										</div>
										<span class="display_currency" id="total_discount">0</span>
									</div>
	
									<div class="item">
										
										<div class="discount-form-wrapper">
											<span><b>@lang( 'sale.order_tax' ):</b>(+)</span>
											<div class="discount-form">
												{!! Form::label('tax_rate_id', __('sale.order_tax') . ':*', ['style' => 'display: none']) !!}
												{!! Form::select('tax_rate_id', $taxes['tax_rates'], $transaction->tax_id, ['placeholder' => __('messages.please_select'), 'data-default'=> $business_details->default_sales_tax], $taxes['attributes']); !!}

												<input type="hidden" name="tax_calculation_amount" id="tax_calculation_amount" 
												value="{{@num_format(optional($transaction->tax)->amount)}}" data-default="{{$business_details->tax_calculation_amount}}">
											</div>
										</div>
										<span class="display_currency" id="order_tax">{{$transaction->tax_amount}}</span>
									</div>
		
									<div class="item">
										@if(!empty($pos_settings['amount_rounding_method']) && $pos_settings['amount_rounding_method'] > 0)
										<small id="round_off">(@lang('lang_v1.round_off'): <span id="round_off_text">0</span>)</small>
										<br/>
										<input type="hidden" name="round_off_amount" 
											id="round_off_amount" value=0>
										@endif
										<span><b>@lang('sale.total_payable'): </b></span>
										<input type="hidden" name="final_total" id="final_total_input">
										<span id="total_payable">0</span>
									</div>
								</div>
								
							</div>
						@endcomponent

						@component('components.widget', ['class' => 'box-solid'])
							
						    <div class="col-md-12">
						    	<div class="form-group">
									{!! Form::label('sell_note',__('sale.sell_note') . ':') !!}
									{!! Form::textarea('sale_note', $transaction->additional_notes, ['class' => 'form-control', 'rows' => 3]); !!}
								</div>
						    </div>
						    <input type="hidden" name="is_direct_sale" value="1">
						@endcomponent
						@component('components.widget', ['class' => 'box-solid'])
			<div class="col-md-4">
				<div class="form-group">
		            {!! Form::label('shipping_details', __('sale.shipping_details')) !!}
		            {!! Form::textarea('shipping_details',$transaction->shipping_details, ['class' => 'form-control','placeholder' => __('sale.shipping_details') ,'rows' => '3', 'cols'=>'30']); !!}
		        </div>
			</div>
			<div class="col-md-4">
				<div class="form-group">
		            {!! Form::label('shipping_address', __('lang_v1.shipping_address')) !!}
		            {!! Form::textarea('shipping_address', $transaction->shipping_address, ['class' => 'form-control','placeholder' => __('lang_v1.shipping_address') ,'rows' => '3', 'cols'=>'30']); !!}
		        </div>
			</div>
			<div class="col-md-4">
				<div class="form-group">
					{!!Form::label('shipping_charges', __('sale.shipping_charges'))!!}
					<div class="input-group">
					<span class="input-group-addon">
					<i class="fa fa-info"></i>
					</span>
					{!!Form::text('shipping_charges',@num_format($transaction->shipping_charges),['class'=>'form-control input_number','placeholder'=> __('sale.shipping_charges')]);!!}
					</div>
				</div>
			</div>
			<div class="clearfix"></div>
			<div class="col-md-4">
				<div class="form-group">
		            {!! Form::label('shipping_status', __('lang_v1.shipping_status')) !!}
		            {!! Form::select('shipping_status',$shipping_statuses, $transaction->shipping_status, ['class' => 'form-control','placeholder' => __('messages.please_select')]); !!}
		        </div>
			</div>
			<div class="col-md-4">
		        <div class="form-group">
		            {!! Form::label('delivered_to', __('lang_v1.delivered_to') . ':' ) !!}
		            {!! Form::text('delivered_to', $transaction->delivered_to, ['class' => 'form-control','placeholder' => __('lang_v1.delivered_to')]); !!}
		        </div>
		    </div>
			<div class="col-md-4">
				<div class="form-group">
					{!! Form::label('delivery_person', __('lang_v1.delivery_person') . ':' ) !!}
					{!! Form::select('delivery_person', $users, $transaction->delivery_person, ['class' => 'form-control select2','placeholder' => __('messages.please_select')]); !!}
				</div>
			</div>
		    @php
		        $shipping_custom_label_1 = !empty($custom_labels['shipping']['custom_field_1']) ? $custom_labels['shipping']['custom_field_1'] : '';

		        $is_shipping_custom_field_1_required = !empty($custom_labels['shipping']['is_custom_field_1_required']) && $custom_labels['shipping']['is_custom_field_1_required'] == 1 ? true : false;

		        $shipping_custom_label_2 = !empty($custom_labels['shipping']['custom_field_2']) ? $custom_labels['shipping']['custom_field_2'] : '';

		        $is_shipping_custom_field_2_required = !empty($custom_labels['shipping']['is_custom_field_2_required']) && $custom_labels['shipping']['is_custom_field_2_required'] == 1 ? true : false;

		        $shipping_custom_label_3 = !empty($custom_labels['shipping']['custom_field_3']) ? $custom_labels['shipping']['custom_field_3'] : '';
		        
		        $is_shipping_custom_field_3_required = !empty($custom_labels['shipping']['is_custom_field_3_required']) && $custom_labels['shipping']['is_custom_field_3_required'] == 1 ? true : false;

		        $shipping_custom_label_4 = !empty($custom_labels['shipping']['custom_field_4']) ? $custom_labels['shipping']['custom_field_4'] : '';
		        
		        $is_shipping_custom_field_4_required = !empty($custom_labels['shipping']['is_custom_field_4_required']) && $custom_labels['shipping']['is_custom_field_4_required'] == 1 ? true : false;

		        $shipping_custom_label_5 = !empty($custom_labels['shipping']['custom_field_5']) ? $custom_labels['shipping']['custom_field_5'] : '';
		        
		        $is_shipping_custom_field_5_required = !empty($custom_labels['shipping']['is_custom_field_5_required']) && $custom_labels['shipping']['is_custom_field_5_required'] == 1 ? true : false;
	        @endphp

	        @if(!empty($shipping_custom_label_1))
	        	@php
	        		$label_1 = $shipping_custom_label_1 . ':';
	        		if($is_shipping_custom_field_1_required) {
	        			$label_1 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_1', $label_1 ) !!}
			            {!! Form::text('shipping_custom_field_1', !empty($transaction->shipping_custom_field_1) ? $transaction->shipping_custom_field_1 : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_1, 'required' => $is_shipping_custom_field_1_required]); !!}
			        </div>
			    </div>
	        @endif
	        @if(!empty($shipping_custom_label_2))
	        	@php
	        		$label_2 = $shipping_custom_label_2 . ':';
	        		if($is_shipping_custom_field_2_required) {
	        			$label_2 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_2', $label_2 ) !!}
			            {!! Form::text('shipping_custom_field_2', !empty($transaction->shipping_custom_field_2) ? $transaction->shipping_custom_field_2 : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_2, 'required' => $is_shipping_custom_field_2_required]); !!}
			        </div>
			    </div>
	        @endif
	        @if(!empty($shipping_custom_label_3))
	        	@php
	        		$label_3 = $shipping_custom_label_3 . ':';
	        		if($is_shipping_custom_field_3_required) {
	        			$label_3 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_3', $label_3 ) !!}
			            {!! Form::text('shipping_custom_field_3', !empty($transaction->shipping_custom_field_3) ? $transaction->shipping_custom_field_3 : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_3, 'required' => $is_shipping_custom_field_3_required]); !!}
			        </div>
			    </div>
	        @endif
	        @if(!empty($shipping_custom_label_4))
	        	@php
	        		$label_4 = $shipping_custom_label_4 . ':';
	        		if($is_shipping_custom_field_4_required) {
	        			$label_4 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_4', $label_4 ) !!}
			            {!! Form::text('shipping_custom_field_4', !empty($transaction->shipping_custom_field_4) ? $transaction->shipping_custom_field_4 : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_4, 'required' => $is_shipping_custom_field_4_required]); !!}
			        </div>
			    </div>
	        @endif
	        @if(!empty($shipping_custom_label_5))
	        	@php
	        		$label_5 = $shipping_custom_label_5 . ':';
	        		if($is_shipping_custom_field_5_required) {
	        			$label_5 .= '*';
	        		}
	        	@endphp

	        	<div class="col-md-4">
			        <div class="form-group">
			            {!! Form::label('shipping_custom_field_5', $label_5 ) !!}
			            {!! Form::text('shipping_custom_field_5', !empty($transaction->shipping_custom_field_5) ? $transaction->shipping_custom_field_5 : null, ['class' => 'form-control','placeholder' => $shipping_custom_label_5, 'required' => $is_shipping_custom_field_5_required]); !!}
			        </div>
			    </div>
	        @endif
	        <div class="col-md-4">
                <div class="form-group">
                    {!! Form::label('shipping_documents', __('lang_v1.shipping_documents') . ':') !!}
                    {!! Form::file('shipping_documents[]', ['id' => 'shipping_documents', 'multiple', 'accept' => implode(',', array_keys(config('constants.document_upload_mimes_types')))]); !!}
                    <p class="help-block">
                    	@lang('purchase.max_file_size', ['size' => (config('constants.document_size_limit') / 1000000)])
                    	@includeIf('components.document_help_text')
                    </p>
                    @php
                    	$medias = $transaction->media->where('model_media_type', 'shipping_document')->all();
                    @endphp
                    @include('sell.partials.media_table', ['medias' => $medias, 'delete' => true])
                </div>
            </div>
	        <div class="clearfix"></div>
	        <div class="col-md-12 text-center">
				<button type="button" class="btn btn-primary btn-sm" id="toggle_additional_expense"> <i class="fas fa-plus"></i> @lang('lang_v1.add_additional_expenses') <i class="fas fa-chevron-down"></i></button>
			</div>
			<div class="col-md-8 col-md-offset-4" id="additional_expenses_div">
				<table class="table table-condensed">
					<thead>
						<tr>
							<th>@lang('lang_v1.additional_expense_name')</th>
							<th>@lang('sale.amount')</th>
						</tr>
					</thead>
					<tbody>
						<tr>
							<td>
								{!! Form::text('additional_expense_key_1', $transaction->additional_expense_key_1, ['class' => 'form-control', 'id' => 'additional_expense_key_1']); !!}
							</td>
							<td>
								{!! Form::text('additional_expense_value_1', @num_format($transaction->additional_expense_value_1), ['class' => 'form-control input_number', 'id' => 'additional_expense_value_1']); !!}
							</td>
						</tr>
						<tr>
							<td>
								{!! Form::text('additional_expense_key_2', $transaction->additional_expense_key_2, ['class' => 'form-control', 'id' => 'additional_expense_key_2']); !!}
							</td>
							<td>
								{!! Form::text('additional_expense_value_2', @num_format($transaction->additional_expense_value_2), ['class' => 'form-control input_number', 'id' => 'additional_expense_value_2']); !!}
							</td>
						</tr>
						<tr>
							<td>
								{!! Form::text('additional_expense_key_3', $transaction->additional_expense_key_3, ['class' => 'form-control', 'id' => 'additional_expense_key_3']); !!}
							</td>
							<td>
								{!! Form::text('additional_expense_value_3', @num_format($transaction->additional_expense_value_3), ['class' => 'form-control input_number', 'id' => 'additional_expense_value_3']); !!}
							</td>
						</tr>
						<tr>
							<td>
								{!! Form::text('additional_expense_key_4', $transaction->additional_expense_key_4, ['class' => 'form-control', 'id' => 'additional_expense_key_4']); !!}
							</td>
							<td>
								{!! Form::text('additional_expense_value_4', @num_format($transaction->additional_expense_value_4), ['class' => 'form-control input_number', 'id' => 'additional_expense_value_4']); !!}
							</td>
						</tr>
					</tbody>
				</table>
			</div>
			<div class="col-md-4 col-md-offset-8">
		    	@if(!empty($pos_settings['amount_rounding_method']) && $pos_settings['amount_rounding_method'] > 0)
		    	<small id="round_off"><br>(@lang('lang_v1.round_off'): <span id="round_off_text">0</span>)</small>
				<br/>
				<input type="hidden" name="round_off_amount" 
					id="round_off_amount" value=0>
				@endif
		    	<div><b>@lang('sale.total_payable'): </b>
					<input type="hidden" name="final_total" id="final_total_input">
					<span id="total_payable">0</span>
				</div>
		    </div>
			@endcomponent
			@if(!empty($common_settings['is_enabled_export']) && $transaction->type != 'sales_order')
				@component('components.widget', ['class' => 'box-solid', 'title' => __('lang_v1.export')])
					<div class="col-md-12 mb-12">
		                <div class="form-check">
		                    <input type="checkbox" name="is_export" class="form-check-input" id="is_export" @if(!empty($transaction->is_export)) checked @endif>
		                    <label class="form-check-label" for="is_export">@lang('lang_v1.is_export')</label>
		                </div>
		            </div>
			        @php
	                	$i = 1;
		            @endphp
		            @for($i; $i <= 6 ; $i++)
		                <div class="col-md-4 export_div" @if(empty($transaction->is_export)) style="display: none;" @endif>
		                    <div class="form-group">
		                        {!! Form::label('export_custom_field_'.$i, __('lang_v1.export_custom_field'.$i).':') !!}
		                        {!! Form::text('export_custom_fields_info['.'export_custom_field_'.$i.']', !empty($transaction->export_custom_fields_info['export_custom_field_'.$i]) ? $transaction->export_custom_fields_info['export_custom_field_'.$i] : null, ['class' => 'form-control','placeholder' => __('lang_v1.export_custom_field'.$i), 'id' => 'export_custom_field_'.$i]); !!}
		                    </div>
		                </div>
		            @endfor
				@endcomponent
			@endif
					</div>
				</div>
				
				<div class="row">
					<div class="col-md-12 text-center">
				    	{!! Form::hidden('is_save_and_print', 0, ['id' => 'is_save_and_print']); !!}
				    	{!! Form::hidden('status', $transaction->status, ['id' => 'status']); !!}
				    	{!! Form::hidden('change_return', 0, ); !!}
						
				    	<button type="button" class="btn btn-primary btn-big" id="submit-sell">@lang('messages.update')</button>
				    	<button type="button" id="save-and-print" class="btn btn-info btn-big">@lang('lang_v1.update_and_print')</button>
				    </div>
				</div>
				@if(in_array('subscription', $enabled_modules))
					@include('sale_pos.partials.recurring_invoice_modal')
				@endif
				{!! Form::close() !!}
			        </div>  
			    </div>
</div>


<div class="modal fade contact_modal" tabindex="-1" role="dialog" aria-labelledby="gridSystemModalLabel">
	@include('contact.create', ['quick_add' => true])
</div>
<!-- /.content -->
<div class="modal fade register_details_modal" tabindex="-1" role="dialog" 
	aria-labelledby="gridSystemModalLabel">
</div>
<div class="modal fade close_register_modal" tabindex="-1" role="dialog" 
	aria-labelledby="gridSystemModalLabel">
</div>
<!-- quick product modal -->
<div class="modal fade quick_add_product_modal" tabindex="-1" role="dialog" aria-labelledby="modalTitle"></div>

@include('sale_pos.partials.configure_search_modal')

@stop

@section('javascript')
	<script src="{{ asset('js/pos.js?v=' . $asset_v) }}"></script>
	<script src="{{ asset('js/product.js?v=' . $asset_v) }}"></script>
	<script src="{{ asset('js/opening_stock.js?v=' . $asset_v) }}"></script>
	
    
@endsection
