<?php

use Illuminate\Database\Capsule\Manager as Capsule;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Events\Dispatcher;

/*
|--------------------------------------------------------------------------
| Register The Composer Auto Loader
|--------------------------------------------------------------------------
|
| Composer provides a convenient, automatically generated class loader
| for our application. We just need to utilize it! We'll require it
| into the script here so that we do not have to worry about the
| loading of any our classes "manually". Feels great to relax.
|
*/

require __DIR__ . '/vendor/autoload.php';

/*
|--------------------------------------------------------------------------
| Set The Default Timezone
|--------------------------------------------------------------------------
|
| Here we will set the default timezone for PHP. PHP is notoriously mean
| if the timezone is not explicitly set. This will be used by each of
| the PHP date and date-time functions throughout the application.
|
*/

date_default_timezone_set('UTC');

/*
 * Prepare the db connection (spoofing that shit)
 */
$capsule = new Capsule;
$capsule->addConnection([
  'driver'   => 'sqlite',
  'database' => ':memory:',
]);
$capsule->setEventDispatcher(new Dispatcher);
$capsule->setAsGlobal();
$capsule->bootEloquent();

$capsule->schema()->dropIfExists('models');

$capsule->schema()->create('models', function (Blueprint $table) {
    $table->increments('id');
    $table->string('string');
    $table->string('email');
    $table->timestamps();
});

/*
 * Load the configuration.
 */
$config = require __DIR__.'/config/html-forms.php';
function config($key = null, $default = null)
{
    global $config;

    if (is_null($key)) {
        return $config;
    }

    $keys = explode('.', $key);
    array_shift($keys);

    $value = $config;
    foreach ($keys as $segment) {
        if (!isset($value[$segment])) {
            return $default;
        }

        $value = $value[$segment];
    }

    return $value;
}